@@ -14,13 +14,13 @@ class NullPertino():
     def listOrgs(self):
         return ["none"]
 
-    def listDevicesIn(self, _, _):
+    def listDevicesIn(self, *args):
         return ""
     
-    def deleteFrom(self, _, _):
+    def deleteFrom(self, *args):
         pass
 
-def destroyNodes(filter):
+def destroyNodes(aFilter):
     onDigitalOcean = digitalOceanHosting()
     name = Env().get("BaseHostName")
     machines = []
@@ -29,16 +29,18 @@ def destroyNodes(filter):
         username = Env().get("Pertino","username")
         password = Env().get("Pertino","password")
         pertinoSdk = PertinoSdk(username, password)
-    except:
+    except Exception as e:
+        print(str(e))
         pertinoSdk = NullPertino()
         
     organization = pertinoSdk.listOrgs()[0]
     
     # split
     for item in Inventory(onDigitalOcean).list(filteredByHost=name):
-        if filter and not filter in item.name:
+        if aFilter and not aFilter in item.name:
             continue
-        machine = pertinoSdk.listDevicesIn(organization, where("hostName").contains(name))
+        pertinoHost = aFilter if aFilter else name
+        machine = pertinoSdk.listDevicesIn(organization, where("hostName").contains(pertinoHost))
         pertinoSdk.deleteFrom(organization, machine)
         machine = Machine(onDigitalOcean, existing=True).name(item.name)
         machine.destroy()
@@ -78,4 +80,4 @@ if __name__ == '__main__':
         exit(0)
     except Exception as e:
         print (str(e))
-        exit(1)
\ No newline at end of file
+        exit(1)
